==> rtkpp_0.8.4.tar.gz: rtkpp/inst/include/RTKpp.h <==
/*--------------------------------------------------------------------*/
/*     Copyright (C) 2004-2014  Inria

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU General Public
    License along with this program; if not, write to the
    Free Software Foundation, Inc.,
    59 Temple Place,
    Suite 330,
    Boston, MA 02111-1307
    USA

    Contact : S..._Dot_I..._At_stkpp_Dot_org (see copyright for ...)
*/

/*
 * Project:  rtkpp::rtkpp
 * created on: 28 juil. 2014
 * Author:   iovleff, S..._Dot_I..._At_stkpp_Dot_org (see copyright for ...)
 **/

/** @file RTKpp.h
 *  @brief In this file we include all the files of the rtkpp projects.
 **/


#ifndef RTKPP_H
#define RTKPP_H


#include "RTKppForward.h"
#include <Rcpp.h>

#include "../projects/Rtkpp/include/STK_RcppTraits.h"
#include "../projects/Rtkpp/include/STK_RcppVector.h"
#include "../projects/Rtkpp/include/STK_RcppMatrix.h"
#include "../projects/Rtkpp/include/STK_RDataHandler.h"
#include "../projects/Rtkpp/include/STK_ClusterFacade.h"
#include "../projects/Rtkpp/include/STK_ClusterLauncher.h"

#include "../projects/Rtkpp/include/Rcpp_wrap.h"
#include "../projects/Rtkpp/include/Rcpp_as.h"

#endif /* RTKPP_H */

==> rtkpp_0.8.5.tar.gz: rtkpp/inst/include/RTKpp.h <==
/*--------------------------------------------------------------------*/
/*     Copyright (C) 2004-2014  Inria

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU General Public
    License along with this program; if not, write to the
    Free Software Foundation, Inc.,
    59 Temple Place,
    Suite 330,
    Boston, MA 02111-1307
    USA

    Contact : S..._Dot_I..._At_stkpp_Dot_org (see copyright for ...)
*/

/*
 * Project:  rtkpp::rtkpp
 * created on: 28 juil. 2014
 * Author:   iovleff, S..._Dot_I..._At_stkpp_Dot_org (see copyright for ...)
 **/

/** @file RTKpp.h
 *  @brief In this file we include all the files of the rtkpp projects.
 **/


#ifndef RTKPP_H
#define RTKPP_H


#include "RTKppForward.h"
#include <Rcpp.h>

#include "../projects/Rtkpp/include/STK_RcppTraits.h"
#include "../projects/Rtkpp/include/STK_RVector.h"
#include "../projects/Rtkpp/include/STK_RMatrix.h"

#include "../projects/Rtkpp/include/STK_RDataHandler.h"
#include "../projects/Rtkpp/include/STK_ClusterFacade.h"
#include "../projects/Rtkpp/include/STK_ClusterLauncher.h"

#include "../projects/Rtkpp/include/STK_wrap.h"

#include "../projects/Rtkpp/include/Rcpp_wrap.h"
#include "../projects/Rtkpp/include/Rcpp_as.h"

#endif /* RTKPP_H */
